@@ -12,6 +12,7 @@ import argparse
 from . import handlers
 from . import devices
 from . import udev
+from . import debug
 from .version import VERSION
 
 
@@ -62,6 +63,22 @@ class UpdateUdevRulesAction(argparse.Action):
         sys.exit(0)
 
 
+class PrintUdevRulesAction(argparse.Action):
+    """Prints udev rules and exit."""
+
+    def __call__(self, parser, namespace, value, option_string=None):
+        print(udev.generate_rules())
+        sys.exit(0)
+
+
+class PrintDebugAction(argparse.Action):
+    """Prints debug informations and exit."""
+
+    def __call__(self, parser, namespace, value, option_string=None):
+        print(debug.get_debug_info())
+        sys.exit(0)
+
+
 def add_main_cli(cli_parser):
     """Adds the main CLI options.
 
@@ -90,8 +107,18 @@ def add_main_cli(cli_parser):
             help="Updates udev rules (Linux only, requires to be run as root)",
             nargs=0,
             action=UpdateUdevRulesAction)
-    # TODO --print-info
-    pass
+
+    cli_parser.add_argument(
+            "--print-udev",
+            help="Prints udev rules and exit",
+            nargs=0,
+            action=PrintUdevRulesAction)
+
+    cli_parser.add_argument(
+            "--print-debug",
+            help="Prints debug informations and exit",
+            nargs=0,
+            action=PrintDebugAction)
 
 
 def add_mouse_cli(cli_parser, mouse_profile):
@@ -113,3 +140,10 @@ def add_mouse_cli(cli_parser, mouse_profile):
             help="Reset all settings to their factory default",
             dest="RESET",
             action="store_true")
+
+    if "firmware_version" in mouse_profile:
+        cli_group.add_argument(
+                "--firmware-version",
+                help="Print the firmware version of the mouse and exit",
+                dest="FIRMWARE_VERSION",
+                action="store_true")
