@@ -139,4 +139,10 @@ profile = {
         "command": [0x59, 0x00],
     },
 
+    "firmware_version": {
+        "report_type": usbhid.HID_REPORT_TYPE_OUTPUT,
+        "command": [0x90, 0x00],
+        "response_length": 2,
+    },
+
 }
