@@ -80,6 +80,28 @@ class Mouse:
         """The mouse product id."""
         return self._mouse_profile["product_id"]
 
+    @property
+    def firmware_version_tuple(self):
+        """The firmware version of the device as a tuple (e.g.``(1, 33)``,
+        ``(0,)`` if not available).
+        """
+        if "firmware_version" not in self._mouse_profile:
+            return (0,)
+        self._hid_write(
+                usbhid.HID_REPORT_TYPE_OUTPUT,
+                data=self._mouse_profile["firmware_version"]["command"])
+        version = self._hid_device.read(
+                self._mouse_profile["firmware_version"]["response_length"],
+                timeout_ms=200)
+        return tuple(version[::-1])
+
+    @property
+    def firmware_version(self):
+        """The firmware version as an human readable string (e.g. ``"1.33"``,
+        ``"0"`` if not available).
+        """
+        return ".".join([str(i) for i in self.firmware_version_tuple])
+
     def reset_settings(self):
         """Sets all settings to their factory default values."""
         for name, setting_info in self._mouse_profile["settings"].items():
@@ -106,6 +128,16 @@ class Mouse:
                 data=self._mouse_profile["save_command"]["command"],
                 packet_length=packet_length)
 
+    def close(self):
+        """Close the device.
+
+        .. WARNING::
+
+           Once called, any access of the Mouse class properties or function
+           may raise an error.
+        """
+        self._hid_device.close()
+
     def _hid_write(self,
                    report_type=usbhid.HID_REPORT_TYPE_OUTPUT,
                    report_id=0x00,
@@ -197,3 +229,12 @@ class Mouse:
                 self._mouse_profile["vendor_id"],
                 self._mouse_profile["product_id"],
                 self._mouse_profile["endpoint"])
+
+    def __del__(self):
+        self.close()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type_, value, traceback):
+        self.close()
